<?php

namespace OrganizationsManagement\Service\Login;

use OrganizationsManagement\Util\Messages;
use OrganizationsManagement\Util\Utilities;
use Teknisa\Libs\Util\Login\UserDataProvider as LibUserDataProvider;

class UserDataProvider extends LibUserDataProvider {

    /** @var \Teknisa\Model\Geral\Repositories\Operador */
    protected $operadorRepository;

    public function __construct($repository, $activeDirectory, $utilities,
                                $entityManager, $environment, $connectionCustom){

        parent::__construct($repository, $activeDirectory, $utilities,
            $entityManager, $environment, $connectionCustom);

        $this->operadorRepository = $entityManager->getRepository(Utilities::GERAL_ENTITY_DIR . 'Operador');
    }

    /**
     * @param $user
     * @param $password
     * @throws \Exception
     * @return array
     */
    public function getUserData($user, $password) {
        $userData = array( 'USER' => false );
        $operator = $this->repository->getOperatorByNmAccessOrEmail($user);
        if(!empty($operator) && $operator['ID']) {
            /** @var \Teknisa\Model\Geral\Entities\Operador $operatorEntity */
            $operatorEntity = $this->operadorRepository->findOneBy(array('cdoperador' => $operator['ID'], 'nrorg' => $operator['ORGANIZATION_ID']));

            if(empty($operatorEntity->getCdfunc())) {
                throw new \Exception(Messages::ERR_FUNC_ONLY_LOGIN);
            }

            $this->updateEntityManagerVPD($operator);
            $userData['USER']           = $operator;
            $userData['ORGANIZATION']   = $this->repository->getOrganizacaoByNrorg($operator['ORGANIZATION_ID']);
            $accessProfile = $this->repository->getPerfAcessParcByNrorgAndNrParcNegocio($operator['ORGANIZATION_ID'], $operator['NRPARCNEGOCIO']);
            $userData['ACCESS_PROFILE'] = $accessProfile;

            $this->getPasswordParameters($operator['ID'], $operator['ORGANIZATION_ID'], $userData);
            $this->getOtherSessionValues($operator, $userData, $accessProfile);
            $this->getIpRestriction($operator['ORGANIZATION_ID'], $userData);

            if($password) {
                $this->validateAD($userData['PASSWORD_PARAMETERS'], $user, $password, $operator['ORGANIZATION_ID']);
            }
        }

        return $userData;
    }
}
